#import "TicSaasSdkPlugin.h"
#import <TIC_SaaS_SDK/TIC_SaaS_SDK.h>

@implementation TicSaasSdkPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"tic_saas_sdk"
            binaryMessenger:[registrar messenger]];
  TicSaasSdkPlugin* instance = [[TicSaasSdkPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getVersion" isEqualToString:call.method]) {
      NSString *sdkVersion = [TICManager getVersion];
      result(sdkVersion);
  } else if ([@"initSDK" isEqualToString:call.method]) { // 初始化
      [[TICManager sharedInstance] initWithSdkAppId:[call.arguments intValue] callback:^(int code, NSString * _Nonnull desc) {
          NSDictionary *resultDic = @{
              @"code" : @(code),
              @"message" : desc?:@""
          };
          result(resultDic);
      }];
  } else if ([@"joinClassroom" isEqualToString:call.method]) { // 加入房间
      TICClassroomConfig *config = [[TICClassroomConfig alloc] init];
      NSDictionary *argumentDic = (NSDictionary *)call.arguments;
      config.classID = argumentDic[@"classID"];
      config.userID = argumentDic[@"userID"];
      config.userToken = argumentDic[@"userToken"];
      config.companyID = @([argumentDic[@"companyID"] intValue]);
      [[TICManager sharedInstance] joinClassroomWith:config succ:^{
          // 弹起控制器
          TICClassroomViewController *vc = [[TICClassroomViewController alloc] initWithClassId:config.classID];
          [(UIViewController *)[TicSaasSdkPlugin tic_getCurrentViewController] presentViewController:vc animated:YES completion:nil];
          NSDictionary *resultDic = @{
              @"code" : @(0),
              @"message" : @"join classroom succ"
          };
          result(resultDic);
      } failed:^(int code, NSString * _Nonnull errMsg) {
          NSDictionary *resultDic = @{
              @"code" : @(code),
              @"message" : errMsg?:@""
          };
          result(resultDic);
      }];
   } else {
    result(FlutterMethodNotImplemented);
  }
}

+ (UIViewController *)tic_getCurrentViewController{
    UIViewController* currentViewController = [self tic_getRootViewController];
    BOOL runLoopFind = YES;
    while (runLoopFind) {
        if (currentViewController.presentedViewController) {
            currentViewController = currentViewController.presentedViewController;
        } else if ([currentViewController isKindOfClass:[UINavigationController class]]) {
          UINavigationController* navigationController = (UINavigationController* )currentViewController;
            currentViewController = [navigationController.childViewControllers lastObject];
        } else if ([currentViewController isKindOfClass:[UITabBarController class]]) {
          UITabBarController* tabBarController = (UITabBarController* )currentViewController;
            currentViewController = tabBarController.selectedViewController;
        } else {
            NSUInteger childViewControllerCount = currentViewController.childViewControllers.count;
            if (childViewControllerCount > 0) {
                currentViewController = currentViewController.childViewControllers.lastObject;
                return currentViewController;
            } else {
                return currentViewController;
            }
        }

    }
    return currentViewController;
}

+ (UIViewController *)tic_getRootViewController{
    UIWindow* window = [[[UIApplication sharedApplication] delegate] window];
    NSAssert(window, @"The window is empty");
    return window.rootViewController;
}

@end
