import 'dart:async';

import 'package:flutter/services.dart';

class TicSaasSdk {
  static const MethodChannel _channel =
      const MethodChannel('tic_saas_sdk');

// 获取 SDK 版本号
  static Future<String> get getVersion async {
    final String version = await _channel.invokeMethod('getVersion');
    return version;
  }

// 初始化 SDK
  static Future<void> initSDK(int sdkappid) async {
    final Map resultMap = await _channel.invokeMethod('initSDK', sdkappid);
    if (resultMap['code'] != 0) {
      String message = resultMap['message'];
      print('初始化SDK失败：$message');
    } else {
      print('初始化SDK成功');
    }
  }

// 加入课堂
    static Future<void> joinClassroom(TICClassroomConfig config) async {
    final Map resultMap = await _channel.invokeMethod('joinClassroom', config.toJson());
        if (resultMap['code'] != 0) {
      String message = resultMap['message'];
      print('加入课堂失败：$message');
    } else {
      print('加入课堂成功');
    }
  }
}

/*
 课堂配置类，加入课堂时需传入这些信息，带✅的为必填项
 */
class TICClassroomConfig {
  String classID;   // 课堂ID✅
  String userID;    // 用户ID✅
  String userToken; // 用户密码✅
  String companyID; // 机构码（腾讯云互动课堂后台为每个注册企业的分配唯一标识码）✅
  String userSig;   // 用户签名（没有在腾讯云互动课堂后台设置IM私钥的，必填；设置了IM私钥的填 nil）
  String password;  // 游客进房密码（游客进房必填，否则不用填）

  TICClassroomConfig(this.classID, this.userID, this.userToken, this.companyID);
  
  Map<String, dynamic> toJson() =>
    <String, dynamic>{
      'classID': this.classID,
      'userID': this.userID,
      'userToken': this.userToken,
      'companyID': this.companyID,
      'userSig': this.userSig,
      'password': this.password
    };
}
